arc3

Function arc3 

pub fn arc3<S: Scalar>(
    p0: Vector3<S>,
    mid: Vector3<S>,
    p2: Vector3<S>,
    w: S,
) -> GeopResult<NurbCurve3D<S>>
A degree-2 rational Bezier curve in 3-D from p0 to p2 through the (weighted) control point mid, with middle weight w. For an arc centered at c with w = sqrt2_over_2(), pass mid = p0 + p2 - c (i.e. c + (p0 - c) + (p2 - c), the sum of the two radius vectors relative to the arc’s actual center, offset back into absolute coordinates) to trace an exact 90-degree circular arc of radius |p0 - c| = |p2 - c|.